@@ -26,6 +26,7 @@ import keras
 import time
 from os import listdir
 import os
+import platform
 import shutil
 from tqdm import tqdm
 from datetime import datetime, timedelta
@@ -40,13 +41,21 @@ import json
 import pickle
 import faulthandler; faulthandler.enable()
 import obspy
+import logging
 from obspy.signal.trigger import trigger_onset
 from .EqT_utils import f1, SeqSelfAttention, FeedForward, LayerNormalization
 warnings.filterwarnings("ignore")
 from tensorflow.python.util import deprecation
 deprecation._PRINT_DEPRECATION_WARNINGS = False
 
-EQT_VERSION = "0.1.56"    
+try:
+    f = open('setup.py')
+    for li, l in enumerate(f):
+        if li == 8:
+            EQT_VERSION = l.split('"')[1]
+except Exception:
+    EQT_VERSION = "0.1.58"
+    
 
 def mseed_predictor(input_dir='downloads_mseeds',
               input_model="sampleData&Model/EqT1D8pre_048.h5",
@@ -63,7 +72,8 @@ def mseed_predictor(input_dir='downloads_mseeds',
               batch_size=500,              
               overlap = 0.3,
               gpuid=None,
-              gpu_limit=None): 
+              gpu_limit=None,
+              overwrite=False): 
     
     """ 
     
@@ -118,6 +128,9 @@ def mseed_predictor(input_dir='downloads_mseeds',
              
     gpu_limit: int
        Set the maximum percentage of memory usage for the GPU. 
+
+    overwrite: Bolean, default=False
+        Overwrite your results automatically.
            
     Returns
     --------        
@@ -160,7 +173,11 @@ def mseed_predictor(input_dir='downloads_mseeds',
         config.gpu_options.allow_growth = True
         config.gpu_options.per_process_gpu_memory_fraction = float(args['gpu_limit']) 
         K.tensorflow_backend.set_session(tf.Session(config=config))          
-                                  
+
+    logging.basicConfig(level=logging.DEBUG,
+                        format='%(asctime)s [%(levelname)s] [%(name)s] %(message)s',
+                        datefmt='%m-%d %H:%M') 
+
     class DummyFile(object):
         file = None
         def __init__(self, file):
@@ -179,10 +196,13 @@ def mseed_predictor(input_dir='downloads_mseeds',
         sys.stdout = save_stdout
     
  
-    print('============================================================================')
-    print('Running EqTransformer ', str(EQT_VERSION))
+    # print('============================================================================')
+    # print('Running EqTransformer ', str(EQT_VERSION))
+    eqt_logger = logging.getLogger("EQTransformer")
+    eqt_logger.info(f"Running EqTransformer  {EQT_VERSION}")
             
-    print(' *** Loading the model ...', flush=True)        
+    # print(' *** Loading the model ...', flush=True)     
+    eqt_logger.info(f"*** Loading the model ...")
     model = load_model(args['input_model'], 
                        custom_objects={'SeqSelfAttention': SeqSelfAttention, 
                                        'FeedForward': FeedForward,
@@ -193,26 +213,40 @@ def mseed_predictor(input_dir='downloads_mseeds',
                   loss_weights = args['loss_weights'],           
                   optimizer = Adam(lr = 0.001),
                   metrics = [f1])
-    print('*** Loading is complete!', flush=True)  
+    # print('*** Loading is complete!', flush=True)  
+    eqt_logger.info(f"*** Loading is complete!")
 
 
     out_dir = os.path.join(os.getcwd(), str(args['output_dir']))
     if os.path.isdir(out_dir):
-        print('============================================================================')        
-        print(f' *** {out_dir} already exists!')
-        inp = input(" --> Type (Yes or y) to create a new empty directory! This will remove your previous results!")
+        # print('============================================================================')        
+        # print(f' *** {out_dir} already exists!')
+        eqt_logger.info(f"*** {out_dir} already exists!")
+        if overwrite == True:
+            inp = "y"
+            eqt_logger.info(f"Overwriting your previous results")
+            # print("Overwriting your previous results")
+        else:
+            inp = input(" --> Type (Yes or y) to create a new empty directory! This will erase your previous results so make a copy if you want them.")
         if inp.lower() == "yes" or inp.lower() == "y":
             shutil.rmtree(out_dir)  
             os.makedirs(out_dir) 
         else:
+            print("Okay.")
             return
      
-    station_list = [ev.split(".")[0] for ev in listdir(args['input_dir']) if ev.split('/')[-1] != '.DS_Store'];
+    if platform.system() == 'Windows':
+        station_list = [ev.split(".")[0] for ev in listdir(args['input_dir']) if ev.split("\\")[-1] != ".DS_Store"];
+    else:     
+        station_list = [ev.split(".")[0] for ev in listdir(args['input_dir']) if ev.split("/")[-1] != ".DS_Store"];
+        
+
     station_list = sorted(set(station_list))
     
     data_track = dict()
 
-    print(f"######### There are files for {len(station_list)} stations in {args['input_dir']} directory. #########", flush=True)
+    # print(f"######### There are files for {len(station_list)} stations in {args['input_dir']} directory. #########", flush=True)
+    eqt_logger.info(f"There are files for {len(station_list)} stations in {args['input_dir']} directory.")
     for ct, st in enumerate(station_list):
     
         save_dir = os.path.join(out_dir, str(st)+'_outputs')
@@ -247,11 +281,16 @@ def mseed_predictor(input_dir='downloads_mseeds',
                                  's_snr'
                                      ])  
         csvPr_gen.flush()
-        print(f'========= Started working on {st}, {ct+1} out of {len(station_list)} ...', flush=True)
+        # print(f'========= Started working on {st}, {ct+1} out of {len(station_list)} ...', flush=True)
+        eqt_logger.info(f"Started working on {st}, {ct+1} out of {len(station_list)} ...")
+        
 
         start_Predicting = time.time()       
+        if platform.system() == 'Windows':
+            file_list = [join(st, ev) for ev in listdir(args["input_dir"]+"\\"+st) if ev.split("\\")[-1].split(".")[-1].lower() == "mseed"]; 
+        else:
+            file_list = [join(st, ev) for ev in listdir(args["input_dir"]+"/"+st) if ev.split("/")[-1].split(".")[-1].lower() == "mseed"]; 
         
-        file_list = [join(st, ev) for ev in listdir(args['input_dir']+'/'+st) if ev.split('/')[-1].split('.')[-1].lower() == 'mseed'];   
         mon = [ev.split('__')[1]+'__'+ev.split('__')[2] for ev in file_list ];
         uni_list = list(set(mon))
         uni_list.sort()  
@@ -260,7 +299,7 @@ def mseed_predictor(input_dir='downloads_mseeds',
         
         # print('============ Station {} has {} chunks of data.'.format(st, len(uni_list)), flush=True)      
         for _, month in enumerate(uni_list):
-            print(month)
+            eqt_logger.info(f"{month}")
             matching = [s for s in file_list if month in s]
             meta, time_slots, comp_types, data_set = _mseed2nparry(args, matching, time_slots, comp_types, st)
 
@@ -294,9 +333,12 @@ def mseed_predictor(input_dir='downloads_mseeds',
                         
         dd = pd.read_csv(os.path.join(save_dir,'X_prediction_results.csv'))
         print(f'\n', flush=True)
-        print(' *** Finished the prediction in: {} hours and {} minutes and {} seconds.'.format(hour, minute, round(seconds, 2)), flush=True)         
-        print(' *** Detected: '+str(len(dd))+' events.', flush=True)
-        print(' *** Wrote the results into --> " ' + str(save_dir)+' "', flush=True)
+        eqt_logger.info(f"Finished the prediction in: {hour} hours and {minute} minutes and {round(seconds, 2)} seconds.")
+        eqt_logger.info(f'*** Detected: '+str(len(dd))+' events.')
+        eqt_logger.info(f' *** Wrote the results into --> " ' + str(save_dir)+' "')
+        # print(' *** Finished the prediction in: {} hours and {} minutes and {} seconds.'.format(hour, minute, round(seconds, 2)), flush=True)         
+        # print(' *** Detected: '+str(len(dd))+' events.', flush=True)
+        # print(' *** Wrote the results into --> " ' + str(save_dir)+' "', flush=True)
         
         with open(os.path.join(save_dir,'X_report.txt'), 'a') as the_file: 
             the_file.write('================== PREDICTION FROM MSEED ===================='+'\n')               
@@ -467,8 +509,11 @@ class PreLoadGeneratorTest(keras.utils.Sequence):
         
     def __len__(self):
         'Denotes the number of batches per epoch'
-        return int(np.floor(len(self.list_IDs) / self.batch_size))
-
+        try:
+            return int(np.floor(len(self.list_IDs) / self.batch_size))
+        except ZeroDivisionError:
+            print("Your data duration in mseed file is too short! Try either longer files or reducing batch_size. ")
+        
     def __getitem__(self, index):
         'Generate one batch of data'
         indexes = self.indexes[index*self.batch_size:(index+1)*self.batch_size]           
@@ -1047,7 +1092,10 @@ def _plotter_prediction(data, args, save_figs, yh1, yh2, yh3, evi, matches):
         plt.plot(data[:, 0], 'k')
         plt.xlim(0, 6000)
         x = np.arange(6000)
-        plt.title(save_figs.split('/')[-2].split('_')[0]+':'+str(evi))
+        if platform.system() == 'Windows':
+            plt.title(save_figs.split("\\")[-2].split("_")[0]+":"+str(evi))
+        else:
+            plt.title(save_figs.split("/")[-2].split("_")[0]+":"+str(evi))
                      
         ax.set_xticks([])
         plt.rcParams["figure.figsize"] = (10, 10)
@@ -1218,8 +1266,12 @@ def _plotter_prediction(data, args, save_figs, yh1, yh2, yh3, evi, matches):
         ax = fig.add_subplot(spec5[0, 0])         
         plt.plot(data[:, 0], 'k')
         x = np.arange(6000)
-        plt.xlim(0, 6000)            
-        plt.title(save_figs.split('/')[-2].split('_')[0]+':'+str(evi))
+        plt.xlim(0, 6000) 
+        
+        if platform.system() == 'Windows':  
+            plt.title(save_figs.split("\\")[-2].split("_")[0]+":"+str(evi))
+        else:
+            plt.title(save_figs.split("/")[-2].split("_")[0]+":"+str(evi))
 
         plt.ylabel('Amplitude\nCounts')
                                           
@@ -1349,4 +1401,4 @@ def _plotter_prediction(data, args, save_figs, yh1, yh2, yh3, evi, matches):
         plt.close(fig)
         plt.clf()
         
-        
\ No newline at end of file
+        
