@@ -13,6 +13,7 @@ from tqdm import tqdm
 import numpy as np
 import json
 import os
+import platform
 import sqlite3 
 import pandas as pd
 import csv
@@ -23,6 +24,7 @@ from obspy import UTCDateTime
 from obspy.signal.trigger import ar_pick
 from obspy.signal.trigger import recursive_sta_lta, trigger_onset
 from itertools import combinations
+from obspy.core.event import Catalog, Event, Origin, Arrival, Pick, WaveformStreamID
 
 
 def run_associator(input_dir,
@@ -35,8 +37,7 @@ def run_associator(input_dir,
     
     """
     
-    It performs a very simple association based on detection times on multiple stations.
-    It works fine when you have a small and local network of seismic stations. 
+    It performs a very simple association based on detection times on multiple stations. It works fine when you have a small and local network of seismic stations. 
 
     Parameters
     ----------
@@ -103,13 +104,19 @@ def run_associator(input_dir,
                                     s_snr NUMERIC,
                                     amp NUMERIC
                                     )''')
-    
-    station_list = [ev for ev in listdir(input_dir) if ev.split('/')[-1] != '.DS_Store'];
+    if platform.system() == 'Windows':
+        station_list = [ev for ev in listdir(input_dir) if ev.split("\\")[-1] != ".DS_Store"];
+    else:
+        station_list = [ev for ev in listdir(input_dir) if ev.split("/")[-1] != ".DS_Store"];
+        
     station_list = sorted(set(station_list))
 
     for st in station_list:       
         print(f'reading {st} ...')
-        _pick_database_maker(conn, cur, input_dir+'/'+st+'/X_prediction_results.csv')
+        if platform.system() == 'Windows':
+            _pick_database_maker(conn, cur, input_dir+"\\"+st+'"\\"X_prediction_results.csv')
+        else:
+            _pick_database_maker(conn, cur, input_dir+"/"+st+'/X_prediction_results.csv')
 
     #  read the database as dataframe 
     conn = sqlite3.connect("phase_dataset")
@@ -301,9 +308,13 @@ def _doubleChecking(station_list, detections, preprocessed_dir, moving_window, t
       #  print(sttt)
         if sttt not in detections['station'].to_list():
             new_picks = {}                    
-        
-            file_name = preprocessed_dir+'/'+sttt+'.hdf5'
-            file_csv = preprocessed_dir+"/"+sttt+".csv"
+            if platform.system() == 'Windows':
+                file_name = preprocessed_dir+"\\"+sttt+".hdf5"
+                file_csv = preprocessed_dir+"\\"+sttt+".csv"
+            else:
+                file_name = preprocessed_dir+"/"+sttt+".hdf5"
+                file_csv = preprocessed_dir+"/"+sttt+".csv"
+            
             df = pd.read_csv(file_csv)
             df['start_time'] = pd.to_datetime(df['start_time'])  
             
@@ -349,8 +360,12 @@ def _dbs_associator(start_time, end_time, moving_window,
                     consider_combination=False):  
     
     if consider_combination==True: 
-        Y2000_writer = open(save_dir+'/'+'Y2000.phs', 'w')
-        traceNmae_dic = dict()    
+        if platform.system() == 'Windows':
+            Y2000_writer = open(save_dir+"\\"+"Y2000.phs", "w")
+        else:
+            Y2000_writer = open(save_dir+"/"+"Y2000.phs", "w")
+            
+        traceNmae_dic = dict()   
         st = datetime.strptime(start_time, '%Y-%m-%d %H:%M:%S.%f')
         et = datetime.strptime(end_time, '%Y-%m-%d %H:%M:%S.%f')
         total_t = et-st;
@@ -374,13 +389,16 @@ def _dbs_associator(start_time, end_time, moving_window,
                 st_lon_DMS = _decimalDegrees2DMS(float(detections.iloc[0]['stlon']),  "Longitude")
                 depth = 5.0
                 mag = 0.0
+
+                # QuakeML
+                print(detections.iloc[0]['event_start_time'])
                       
                 if len(detections)/pair_n <= 2:
                     ch = pair_n
                 else:
                     ch = int(len(detections)-pair_n)
                   
-                                    
+                picks = []            
                 for ns in range(ch, len(detections)+1):
                     comb = 0
                     for ind in list(combinations(detections.index, ns)):
@@ -429,9 +447,14 @@ def _dbs_associator(start_time, end_time, moving_window,
                                 hrp = "{:>2}".format(str(row['p_arrival_time']).split(' ')[1].split(':')[0]) 
                                 mip = "{:>2}".format(str(row['p_arrival_time']).split(' ')[1].split(':')[1]) 
                                 sec_p = "{:>4}".format(str(row['p_arrival_time']).split(' ')[1].split(':')[2]) 
+                                p = Pick(time=UTCDateTime(row['p_arrival_time']), 
+                                         waveform_id=WaveformStreamID(network_code=network,
+                                         station_code=station.rstrip()),
+                                         phase_hint="P")
+                                picks.append(p)
                             except Exception:
                                 sec_p = None
-                                
+
                             try:
                                 yrs = "{:>4}".format(str(row['s_arrival_time']).split(' ')[0].split('-')[0])
                                 mos = "{:>2}".format(str(row['s_arrival_time']).split(' ')[0].split('-')[1]) 
@@ -439,6 +462,10 @@ def _dbs_associator(start_time, end_time, moving_window,
                                 hrs = "{:>2}".format(str(row['s_arrival_time']).split(' ')[1].split(':')[0]) 
                                 mis = "{:>2}".format(str(row['s_arrival_time']).split(' ')[1].split(':')[1])                                 
                                 sec_s = "{:>4}".format(str(row['s_arrival_time']).split(' ')[1].split(':')[2]) 
+                                p = Pick(time=UTCDateTime(row['p_arrival_time']), 
+                                         waveform_id=WaveformStreamID(network_code=network, station_code=station.rstrip()),
+                                         phase_hint="S")
+                                picks.append(p)
                             except Exception:
                                 sec_s = None
                             
@@ -492,13 +519,21 @@ def _dbs_associator(start_time, end_time, moving_window,
     
         print('The Number of Realizations: '+str(evid)+'\n', flush=True)
             
-        jj = json.dumps(traceNmae_dic)     
-        f = open(save_dir+'/'+"traceNmae_dic.json","w")
+        jj = json.dumps(traceNmae_dic) 
+        if platform.system() == 'Windows':
+            f = open(save_dir+"\\"+"traceNmae_dic.json","w")
+        else:
+            f = open(save_dir+"/"+"traceNmae_dic.json","w")
         f.write(jj)
         f.close()
 
-    else:    
-        Y2000_writer = open(save_dir+'/'+'Y2000.phs', 'w')
+    else:  
+        if platform.system() == 'Windows':
+            Y2000_writer = open(save_dir+"\\"+"Y2000.phs", "w")
+        else:
+            Y2000_writer = open(save_dir+"/"+"Y2000.phs", "w")
+            
+        cat = Catalog()
         traceNmae_dic = dict()    
         st = datetime.strptime(start_time, '%Y-%m-%d %H:%M:%S.%f')
         et = datetime.strptime(end_time, '%Y-%m-%d %H:%M:%S.%f')
@@ -527,12 +562,20 @@ def _dbs_associator(start_time, end_time, moving_window,
                                                                                              int(hr),int(mi),float(sec), 
                                                                                              float(st_lat_DMS[0]), str(st_lat_DMS[1]), float(st_lat_DMS[2]),
                                                                                              float(st_lon_DMS[0]), str(st_lon_DMS[1]), float(st_lon_DMS[2]),
-                                                                                             float(depth), float(mag)));            
+                                                                                             float(depth), float(mag)));          
+                event = Event()
+                origin = Origin(time=UTCDateTime(detections.iloc[0]['event_start_time']),
+                                longitude=detections.iloc[0]['stlon'],
+                                latitude=detections.iloc[0]['stlat'],
+                                method="EqTransformer")
+                event.origins.append(origin)
+                
                 station_buffer = []
                 row_buffer = []
                 sorted_detections = detections.sort_values('p_arrival_time')
                 tr_names = []
                 tr_names2 = []
+                picks = []
                 for _, row in sorted_detections.iterrows():
                     trace_name = row['traceID']+'*'+row['station']+'*'+str(row['event_start_time'])
                     p_unc = row['p_unc']
@@ -559,7 +602,7 @@ def _dbs_associator(start_time, end_time, moving_window,
                         Sweihgt = 4
                         
                     station = "{:<5}".format(row['station'])
-                    network = "{:<2}".format(row['network']) 
+                    network = "{:<2}".format(row['network'])
                     
                     try:
                         yrp = "{:>4}".format(str(row['p_arrival_time']).split(' ')[0].split('-')[0])
@@ -568,6 +611,10 @@ def _dbs_associator(start_time, end_time, moving_window,
                         hrp = "{:>2}".format(str(row['p_arrival_time']).split(' ')[1].split(':')[0]) 
                         mip = "{:>2}".format(str(row['p_arrival_time']).split(' ')[1].split(':')[1]) 
                         sec_p = "{:>4}".format(str(row['p_arrival_time']).split(' ')[1].split(':')[2]) 
+                        p = Pick(time=UTCDateTime(row['p_arrival_time']), 
+                                     waveform_id=WaveformStreamID(network_code=network, station_code=station.rstrip()),
+                                     phase_hint="P", method_id="EqTransformer")
+                        picks.append(p)
                     except Exception:
                         sec_p = None
 
@@ -578,6 +625,10 @@ def _dbs_associator(start_time, end_time, moving_window,
                         hrs = "{:>2}".format(str(row['s_arrival_time']).split(' ')[1].split(':')[0]) 
                         mis = "{:>2}".format(str(row['s_arrival_time']).split(' ')[1].split(':')[1])                                 
                         sec_s = "{:>4}".format(str(row['s_arrival_time']).split(' ')[1].split(':')[2]) 
+                        p = Pick(time=UTCDateTime(row['s_arrival_time']), 
+                                     waveform_id=WaveformStreamID(network_code=network, station_code=station.rstrip()),
+                                     phase_hint="S", method_id="EqTransformer")
+                        picks.append(p)
                     except Exception:
                         sec_s = None                              
     
@@ -608,6 +659,9 @@ def _dbs_associator(start_time, end_time, moving_window,
                                                                                                          int(yrp),int(mop),int(dyp),
                                                                                                          int(hrp),int(mip),float(sec_p),
                                                                                                          float(0.0))); 
+                event.picks = picks
+                event.preferred_origin_id = event.origins[0].resource_id
+                cat.append(event)
     
                 evid += 1
                 Y2000_writer.write("{:<62}".format(' ')+"%10d"%(evid)+'\n');
@@ -642,8 +696,14 @@ def _dbs_associator(start_time, end_time, moving_window,
             
         print('The Number of Associated Events: '+str(evid-200000)+'\n', flush=True)
             
-        jj = json.dumps(traceNmae_dic)     
-        f = open(save_dir+'/'+"traceNmae_dic.json","w")
+        jj = json.dumps(traceNmae_dic)  
+        if platform.system() == 'Windows':
+            f = open(save_dir+"\\"+"traceNmae_dic.json","w")
+        else:    
+            f = open(save_dir+"/"+"traceNmae_dic.json","w")
+            
         f.write(jj)
         f.close()
+        print(cat.__str__(print_all=True))
+        cat.write(save_dir+"/associations.xml", format="QUAKEML")
         
