@@ -13,6 +13,7 @@ from obspy.clients.fdsn.mass_downloader import RectangularDomain, Restrictions,
 from obspy import UTCDateTime
 import datetime
 import os
+import platform
 from obspy.clients.fdsn.client import Client
 import shutil
 from multiprocessing.pool import ThreadPool
@@ -20,7 +21,7 @@ import multiprocessing
 import numpy as np
 
 
-def makeStationList(client_list, min_lat, max_lat, min_lon, max_lon, start_time, end_time, channel_list=[], filter_network=[], filter_station=[]):
+def makeStationList(json_path,client_list, min_lat, max_lat, min_lon, max_lon, start_time, end_time, channel_list=[], filter_network=[], filter_station=[],**kwargs):
 
 
      """
@@ -29,6 +30,9 @@ def makeStationList(client_list, min_lat, max_lat, min_lon, max_lon, start_time,
 
     Parameters
     ----------
+    json_path: str
+        Path of the json file that will be returned
+
     client_list: list
         List of client names e.g. ["IRIS", "SCEDC", "USGGS"].
                                 
@@ -59,6 +63,9 @@ def makeStationList(client_list, min_lat, max_lat, min_lon, max_lon, start_time,
     filter_station: str, default=[]
         A list containing the station names that need to be avoided.
 
+    kwargs: 
+        special symbol for passing Client.get_stations arguments
+
     Returns
     ----------
     stations_list.json: A dictionary containing information for the available stations.      
@@ -73,16 +80,16 @@ def makeStationList(client_list, min_lat, max_lat, min_lon, max_lon, start_time,
                                      maxlongitude=max_lon, 
                                      starttime=UTCDateTime(start_time), 
                                      endtime=UTCDateTime(end_time), 
-                                     level='channel')    
+                                     level='channel',**kwargs)    
 
          for ev in inventory:
              net = ev.code
              if net not in filter_network:
                  for st in ev:
                      station = st.code
+                     print(str(net)+"--"+str(station))
     
                      if station not in filter_station:
-                         print(str(net)+"--"+str(station))
 
                          elv = st.elevation
                          lat = st.latitude
@@ -112,19 +119,18 @@ def makeStationList(client_list, min_lat, max_lat, min_lon, max_lon, start_time,
     #                              new_chan = new_chan2 
     # ============================================================================= 
                         
-                         if station not in station_list:
+                         if len(new_chan) > 0 and (station not in station_list):
                              station_list[str(station)] ={"network": net,
                                                       "channels": list(set(new_chan)),
                                                       "coords": [lat, lon, elv]
                                                       }
-
-     with open('station_list.json', 'w') as fp:
+     json_dir = os.path.dirname(json_path)
+     if not os.path.exists(json_dir):
+         os.makedirs(json_dir)
+     with open(json_path, 'w') as fp:
          json.dump(station_list, fp)
          
          
-         
-         
-         
 def downloadMseeds(client_list, stations_json, output_dir, start_time, end_time, min_lat, max_lat, min_lon, max_lon, chunk_size, channel_list=[], n_processor=None):
     
     
@@ -263,14 +269,26 @@ def downloadSacs(client, stations_json, output_dir, start_time, end_time, patien
     fr = open(stations_json, 'r'); 
     new_list = json.load(fr)
     print(f"####### There are {len(new_list)} stations in the list. #######")
-    if not os.path.exists(output_dir+"/"):
-        os.makedirs(output_dir+"/")  
+
+    if platform.system() == 'Windows':
+        if not os.path.exists(output_dir+"\\"):
+            os.makedirs(output_dir+"\\")  
+    else:        
+        if not os.path.exists(output_dir+"/"):
+            os.makedirs(output_dir+"/")  
 
     def process(station):          
         net = new_list[station]['network']
-        dirname = str(station)+'/'
-        if not os.path.exists(dirname):
-            os.makedirs(dirname)            
+        
+        if platform.system() == 'Windows':
+            dirname = str(station)+"\\"
+            if not os.path.exists(dirname):
+                os.makedirs(dirname) 
+        else:   
+            dirname = str(station)+"/"
+            if not os.path.exists(dirname):
+                os.makedirs(dirname)  
+                
         chans = new_list[station]['channels']  
         
         for chan in chans:
